@@ -15,9 +15,4 @@
   (loop FOR beg = 0 THEN (+ end len)
         FOR end = (search delim seq :start2 beg)
         COLLECT (subseq seq beg end)
-        WHILE end))
-
-(defmacro muffle-warn (&body body)
-  `(locally 
-    #+SBCL (declare (sb-ext:muffle-conditions sb-ext:compiler-note))
-    ,@body))
\ No newline at end of file
+        WHILE end))
\ No newline at end of file
